/*-----------------------------------------------------------------------
dreams_table1.do

Stata do file to replicate table 1 of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

* read panel
use ../../data/processed/nlsy_panel_sample, clear

* restrict sample to test year (1980)
keep if year == 1980

* pairwise correlation entire sample
pwcorr self_pctl afqt_pctl
disp "entire sample"
disp `r(rho)'
count

*  pairwise correlations by education level
pwcorr self_pctl afqt_pctl if educ_highest_life <= 12
disp "at most high school"
disp `r(rho)'
count if educ_highest_life <= 12
pwcorr self_pctl afqt_pctl if educ_highest_life > 12
disp "more than high school"
disp `r(rho)'
count if educ_highest_life > 12

** table
* pairwise correlations by age and education level
pwcorr self_pctl afqt_pctl if educ_highest_life <= 12 & (age == 15 | age == 16 | age == 17)
disp "at most high school | ages 16, 17"
local pwc_1 : di %9.3f `r(rho)'
disp `pwc_1'
count if educ_highest_life <= 12 & (age == 15 | age == 16 | age == 17)
pwcorr self_pctl afqt_pctl if educ_highest_life > 12 & (age == 15 | age == 16 | age == 17)
disp "more than high school | ages 16, 17"
local pwc_2 : di %9.3f `r(rho)'
disp `pwc_2'
count if educ_highest_life > 12 & (age == 15 | age == 16 | age == 17)

pwcorr self_pctl afqt_pctl if educ_highest_life <= 12 & (age == 18 | age == 19)
disp "at most high school | ages 18, 19"
local pwc_3 : di %9.3f `r(rho)'
disp `pwc_3'
count if educ_highest_life <= 12 & (age == 18 | age == 19)
pwcorr self_pctl afqt_pctl if educ_highest_life > 12 & (age == 18 | age == 19)
disp "more than high school | ages 18, 19"
local pwc_4 : di %9.3f `r(rho)'
disp `pwc_4'
count if educ_highest_life > 12 & (age == 18 | age == 19)

pwcorr self_pctl afqt_pctl if educ_highest_life <= 12 & (age == 20 | age == 21)
disp "at most high school | ages 20, 21"
local pwc_5 : di %9.3f `r(rho)'
disp `pwc_5'
count if educ_highest_life <= 12 & (age == 20 | age == 21)
pwcorr self_pctl afqt_pctl if educ_highest_life > 12 & (age == 20 | age == 21)
disp "more than high school | ages 20, 21"
local pwc_6 : di %9.3f `r(rho)'
disp `pwc_6'
count if educ_highest_life > 12 & (age == 20 | age == 21)

pwcorr self_pctl afqt_pctl if educ_highest_life <= 12 & (age == 22 | age == 23)
disp "at most high school | ages 22, 23"
local pwc_7 : di %9.3f `r(rho)'
disp `pwc_7'
count if educ_highest_life <= 12 & (age == 22 | age == 23)
pwcorr self_pctl afqt_pctl if educ_highest_life > 12 & (age == 22 | age == 23)
disp "more than high school | ages 22, 23"
local pwc_8 : di %9.3f `r(rho)'
disp `pwc_8'
count if educ_highest_life > 12 & (age == 22 | age == 23)

* write latex file
file open texfile using ../../results/dreams_table1.tex, write replace
file write texfile "15--17  & " `"`pwc_1'"' " & " `"`pwc_2'"' "\\[1.0ex]" _n
file write texfile "18--19  & " `"`pwc_3'"' " & " `"`pwc_4'"' "\\[1.0ex]" _n
file write texfile "20--21  & " `"`pwc_5'"' " & " `"`pwc_6'"' "\\[1.0ex]" _n
file write texfile "22--23  & " `"`pwc_7'"' " & " `"`pwc_8'"' "\\[1.0ex]" _n
file close texfile
