/*-----------------------------------------------------------------------
dreams_table2.do

Stata do file to replicate table 2 of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

* read panel
use ../../data/processed/nlsy_panel_sample, clear
sort person_id year

* determine location when junior
gen cbsa_jr = cbsa if junior_period == 1
egen cbsa_junior = max(cbsa_jr), by (person_id)
gen fips_jr = fips if junior_period == 1
egen fips_junior = max(fips_jr), by (person_id)

* create indicator for having moved between junior period and senior period
gen moved = 0 if senior_period == 1
replace moved = 1 if moved == 0 & cbsa != cbsa_junior & !missing(cbsa) & !missing(cbsa_junior)
replace moved = 1 if moved == 0 & cbsa != cbsa_junior & missing(cbsa) & !missing(cbsa_junior) & fips != fips_junior
replace moved = 1 if moved == 0 & cbsa != cbsa_junior & !missing(cbsa) & missing(cbsa_junior) & fips != fips_junior
replace moved = 1 if moved == 0 & missing(cbsa) & missing(cbsa_junior) & fips != fips_junior

** dependent variables
replace cbsa_pop2010 = 0 if missing(cbsa_pop2010)
* in big city during junior period
gen big = (cbsa_pop2010 >= $size_big)
gen big_jr = 1 if junior_period == 1 & big == 1
replace big_jr = 0 if junior_period == 1 & big == 0
egen big_junior = max(big_jr), by (person_id)
* in big city during senior period
gen big_senior = 1 if senior_period == 1 & big == 1
replace big_senior = 0 if senior_period == 1 & big == 0
* multinomial logit dependent variable (4 categories)
gen j_s = 0 if big_junior == 0 & big_senior == 0
replace j_s = 1 if big_junior == 0 & big_senior == 1
replace j_s = 2 if big_junior == 1 & big_senior == 1
replace j_s = 3 if big_junior == 1 & big_senior == 0

** minor adjustments
* only 1 individual was born in 1965 (replace by 1964)
replace birth_year = 1964 if birth_year == 1965
* replace missing cbsa with fips to cluster standard errors
gen cbsa_cluster = cbsa * 100
replace cbsa_cluster = fips if missing(cbsa_cluster)

** table
* label variables
label var self_pctl "Self-confidence percentile"
label var afqt_pctl "Ability percentile"
label var sex "Male"
label var hispanic "Hispanic"
label var black "Black"
label var educ_high_school "High-school graduate"
label var educ_some_college "Some college"
label var educ_college "College graduate"
label var never_married "Never married"
label var any_children "One or more children"
label var spouse_work_ft "Full-time working spouse"
label var cbsa_at14_small "In a small city at age 14"
* define controls
local controls "self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft"
local tablecontrols "self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft cbsa_at14_small"
* estimation
mlogit j_s `controls' cbsa_at14_small, rrr cluster(cbsa_cluster)
* write latex file
estimates store log2
estout log2 using "../../results/dreams_table2.tex", keep(`tablecontrols') order(`tablecontrols') cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) starlevels($^{*}$ 0.10 $^{**}$ 0.05 $^{***}$ 0.01) substitute( "(" "\raisebox{.7ex}[0pt]{\scriptsize (" ")" ")}") label collabels(,none) eqlabels(,none) mlabels(,none) nonumbers noomitted stats(N r2_p, labels("Observations" "Pseudo \$R^2$") fmt(%9.0fc %9.4f)) eform unstack style(tex) replace
estimates drop log2

sum self_pctl afqt_pctl, detail
