/*-----------------------------------------------------------------------
dreams_table3.do

Stata do file to replicate table 3 of the article
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

local bigger = 1000000
local smaller = 5000000

* read panel
use ../../data/processed/nlsy_panel_sample, clear
sort person_id year

* create indicator for having moved between age 14 and junior period
gen moved = 0 if junior_period == 1 & !missing(cbsa_at14_small)
replace moved = 1 if moved == 0 & cbsa != cbsa_at14 & !missing(cbsa) & !missing(cbsa_at14)
replace moved = 1 if moved == 0 & cbsa != cbsa_at14 & missing(cbsa) & !missing(cbsa_at14) & fips != fips_at14
replace moved = 1 if moved == 0 & cbsa != cbsa_at14 & !missing(cbsa) & missing(cbsa_at14) & fips != fips_at14
replace moved = 1 if moved == 0 & missing(cbsa) & missing(cbsa_at14) & fips != fips_at14

** dependent variables
replace cbsa_pop2010 = 0 if missing(cbsa_pop2010)
* in big city during junior period
gen big = (cbsa_pop2010 >= $size_big) & !missing(cbsa_pop2010)
gen big_junior = 1 if junior_period == 1 & big == 1
replace big_junior = 0 if junior_period == 1 & big == 0
* in a small city during junior period
gen small_junior = 1 if big_junior == 0
replace small_junior = 0 if big_junior == 1
* moved to a bigger city when junior
gen bigger_junior = 1 if cbsa_pop2010 > cbsa_at14_pop2010 & cbsa_pop2010 >= `bigger' & moved == 1
replace bigger_junior = 0 if missing(bigger_junior) & moved == 1
* moved to a smaller city when junior
gen smaller_junior = 1 if cbsa_pop2010 < cbsa_at14_pop2010 & cbsa_pop2010 < `smaller' & moved == 1
replace smaller_junior = 1 if cbsa_pop2010 == 0 & cbsa_at14_pop2010 == 0 & moved == 1
replace smaller_junior = 0 if missing(smaller_junior) & moved == 1

** minor adjustments
* only 1 individual was born in 1965 (replace by 1964)
replace birth_year = 1964 if birth_year == 1965
* replace missing cbsa with fips to cluster standard errors
gen cbsa_cluster = cbsa * 100
replace cbsa_cluster = fips if missing(cbsa_cluster)

** table
* label variables
label var self_pctl "Self-confidence percentile"
label var afqt_pctl "Ability percentile"
label var sex "Male"
label var hispanic "Hispanic"
label var black "Black"
label var educ_high_school "High-school graduate"
label var educ_some_college "Some college"
label var educ_college "College graduate"
label var never_married "Never married"
label var any_children "One or more children"
label var spouse_work_ft "Full-time working spouse"
label var cbsa_at14_small "In a small city at age 14"
* define controls
local tablecontrols "self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft cbsa_at14_small"
local controls      "self_pctl afqt_pctl sex hispanic black educ_high_school educ_some_college educ_college never_married any_children spouse_work_ft i.birth_year"
* determinants of location in big and small cities, junior period
* column (1), living in big city when junior, full sample
logit big_junior `controls' cbsa_at14_small, or cluster(cbsa_cluster)
estimates store log3_a
* column (2), living in a big city when junior, living in small city at 14
logit big_junior `controls' if cbsa_at14_small == 1, or cluster(cbsa_cluster)
estimates store log3_b
* column (3), living in a bigger city when junior, living in small city at 14 (only movers)
logit bigger_junior `controls' if cbsa_at14_small == 1 & moved == 1, or cluster(cbsa_cluster)
estimates store log3_c
* column (4), living in a small city when junior, living in big city at 14
logit small_junior `controls' if cbsa_at14_small == 0, or cluster(cbsa_cluster)
estimates store log3_d
* column (5), living in a smaller city when junior, living in big city at 14 (only movers)
logit smaller_junior `controls' if cbsa_at14_small == 0 & moved == 1, or cluster(cbsa_cluster)
estimates store log3_e
* write latex file
estout log3_* using "../../results/dreams_table3.tex", keep(`tablecontrols') order(`tablecontrols') cells(b(star fmt(%9.4f)) se(par fmt(%9.4f))) starlevels($^{*}$ 0.10 $^{**}$ 0.05 $^{***}$ 0.01) substitute( "(" "\raisebox{.7ex}[0pt]{\scriptsize (" ")" ")}") label collabels(,none) eqlabels(,none) mlabels(,none) nonumbers noomitted stats(N r2_p, labels("Observations" "Pseudo \$R^2$") fmt(%9.0fc %9.4f)) eform unstack style(tex) replace
estimates drop log3_*

sum self_pctl afqt_pctl, detail
