/*-----------------------------------------------------------------------
nlsy_panel_sample.do

Stata do file to prepare nlsy panel created by nlsy_panel.do for
'City of dreams',
by Jorge De la Roca, Gianmarco Ottaviano and Diego Puga,
Journal of the European Economic Association

Adds cbsa codes, creates junior/senior periods, controls, final sample for estimations
-----------------------------------------------------------------------*/

* initialise
clear
set more off
set varabbrev off

local senior = 10

tempfile tmp
tempfile tmp_fips

use ../../data/processed/nlsy_panel, clear

** assign cbsa codes
* assign cbsa codes and cbsa population for county at age of birth
preserve
import excel "../../data/src/cbsa/CBSA_def2009.xls", cellrange(A5:L1866) clear
rename (A F K) (metroid metro_status fips_birth)
destring metroid metro_status fips_birth, replace
save `tmp', replace
restore
merge m:1 fips_birth using `tmp', keepusing(metroid metro_status) keep(master match) nogen
merge m:1 metroid using "../../data/src/cbsa/metro_1980_2010", keepusing(metroname m_t_a_10) keep(master match) nogen
rename (metroid metro_status metroname m_t_a_10) (cbsa_birth cbsa_birth_type cbsa_birth_name cbsa_birth_pop2010)
* assign cbsa codes and cbsa population for county at age 14
preserve
import excel "../../data/src/cbsa/CBSA_def2009.xls", cellrange(A5:L1866) clear
rename (A F K) (metroid metro_status fips_at14)
destring metroid metro_status fips_at14, replace
save `tmp', replace
restore
merge m:1 fips_at14 using `tmp', keepusing(metroid metro_status) keep(master match) nogen
merge m:1 metroid using "../../data/src/cbsa/metro_1980_2010", keepusing(metroname m_t_a_10) keep(master match) nogen
rename (metroid metro_status metroname m_t_a_10) (cbsa_at14 cbsa_at14_type cbsa_at14_name cbsa_at14_pop2010)
* assign cbsa codes and cbsa population for each county throughout 1979-2012
preserve
import excel "../../data/src/cbsa/CBSA_def2009.xls", cellrange(A5:L1866) clear
rename (A F K) (metroid metro_status fips)
destring metroid metro_status fips, replace
tempfile tmp4
save "`tmp'", replace
restore
merge m:1 fips using `tmp', keepusing(metroid metro_status) keep(master match) nogen
merge m:1 metroid using "../../data/src/cbsa/metro_1980_2010", keepusing(metroname m_t_a_10) keep(master match) nogen
rename (metroid metro_status metroname m_t_a_10) (cbsa cbsa_type cbsa_name cbsa_pop2010)

** sample restrictions
* drop if afqt or 1980 self-confidence score are missing
drop if missing(afqt_80) | missing(self_80_zpctl)
* drop if missing location data
drop if missing(fips)
* make sure all fips codes are valid
preserve
import excel ../../data/src/cbsa/state_county.xls, cellrange(A3:F3143) clear
rename B fips
gen fips_at14 = fips
gen fips_birth = fips
save "`tmp_fips'", replace
restore
merge m:1 fips using "`tmp_fips'", keep(match) keepusing(fips) nogen

** identify junior and senior periods
* junior period: living in a big city after one year of completing highest level of education
* (note: education spells after a 3 year-gap are excluded)
sort person_id year
* identify gaps
egen educ_highest_life = max(educ_highest), by (person_id)
preserve
* for individuals with post-secondary education look at gaps after high school
drop if educ_highest <= 11 & educ_highest_life > 12
* grade unchanged for 3 interviews
gen repeat = 1 if person_id == person_id[_n+1] & educ_highest == educ_highest[_n+1] & person_id == person_id[_n+2] & educ_highest == educ_highest[_n+2] & educ_highest < educ_highest_life
* grade unchanged for 2 interviews separated by more than 2 years
replace repeat = 1 if person_id == person_id[_n+1] & educ_highest == educ_highest[_n+1] & year < year[_n+1] - 2 & educ_highest < educ_highest_life
* pick first instance
egen count = seq() if repeat == 1, by (person_id)
replace count = . if count > 1 & !missing(count)
egen hasgap = max(count), by (person_id)
* individuals with gap
codebook person_id if hasgap == 1
rename count young_
keep person_id year young_ hasgap
save `tmp', replace
restore
merge 1:1 person_id year using `tmp'
drop _merge
* if no gaps, year max education achieved
gen last_educ = 1 if educ_highest == educ_highest_life & hasgap != 1
egen count = seq() if last_educ == 1, by (person_id)
replace count = . if count > 1 & !missing(count)
replace young_ = count if hasgap != 1
* young
gen young = .
* interview after completing education when young_ if not more than two years later
replace young = 1 if person_id == person_id[_n-1] & young_[_n-1] == 1 & year - year[_n-1] <= 2 & age >= 18 & age <= 30
* deal with hs dropouts before 1979
egen max_young = max(young), by (person_id)
replace young = 1 if missing(max_young) & person_id == person_id[_n-2] & young_[_n-2] == 1 & year - year[_n-2] <= 3 & age >= 18 & age <= 30
drop max_young
egen max_young = max(young), by (person_id)
replace young = 1 if missing(max_young) & person_id == person_id[_n-3] & young_[_n-3] == 1 & year - year[_n-3] <= 3 & age >= 18 & age <= 30
drop max_young
drop young_ hasgap last_educ count
* junior period
gen junior_period = young
* senior period
* identify individual age 10 years after completing education
* if a match at a given age can not be made, look for the closest age available
* e.g. if individual is 35 years old after 10 years of completing education, then pick age 34 if it is not observed at 35
* this can be due to a non-interview in that year or the bi-annual nature of interviews after 1994
gen age_sen_ = age if junior_period == 1
replace age_sen_ = age_sen_ + `senior'
egen age_sen = min(age_sen_), by (person_id)
gen match = 1 if age == age_sen
egen miss_match = max(match), by (person_id)
replace match = 1 if age == age_sen - 1 & missing(miss_match)
drop miss_match
egen miss_match = max(match), by (person_id)
replace match = 1 if age == age_sen + 1 & missing(miss_match)
drop miss_match
egen miss_match = max(match), by (person_id)
replace match = 1 if age == age_sen - 2 & missing(miss_match)
drop miss_match
egen miss_match = max(match), by (person_id)
replace match = 1 if age == age_sen + 2 & missing(miss_match)
* senior period
gen senior_period = match

** additional sample restrictions
* keep only observations with junior period location
egen max = max(junior_period), by (person_id)
drop if missing(max)
drop max

** demographics
* race and marital status
gen hispanic = 1 if race == 1
replace hispanic = 0 if missing(hispanic)
gen black = 1 if race == 2
replace black = 0 if missing(black)
gen never_married = 1 if marital == 1
replace never_married = 0 if missing(never_married)
gen married = 1 if marital == 2
replace married = 0 if missing(married)
* children under 7
gen child_under7 = 0
replace child_under7 = 1 if any_children == 1 & agechildren < 7
drop children agechildren
* education
gen educ_high_school = 1 if educ_highest == 12
replace educ_high_school = 0 if missing(educ_high_school)
gen educ_some_college = 1 if educ_highest > 12 & educ_highest < 16
replace educ_some_college = 0 if missing(educ_some_college)
gen educ_college = 1 if educ_highest >= 16 & !missing(educ_highest)
replace educ_college = 0 if missing(educ_college)
* working spouse
gen spouse_work_26w = 1 if spouse_wkswk >= 26 & !missing(spouse_wkswk)
replace spouse_work_26w = 0 if missing(spouse_work_26w)
gen spouse_work_48w = 1 if spouse_wkswk >= 48 & !missing(spouse_wkswk)
replace spouse_work_48w = 0 if missing(spouse_work_48w)
gen spouse_work_ft = 1 if spouse_hrswk >= 40 & !missing(spouse_hrswk)
replace spouse_work_ft = spouse_work_ft == .

** early location
* replace invalid fips codes at birth and at age 14 with missing values
merge m:1 fips_birth using "`tmp_fips'", keep(master match) keepusing(fips_birth)
replace fips_birth = . if !missing(fips_birth) & _merge == 1
drop _merge
merge m:1 fips_at14 using "`tmp_fips'", keep(master match) keepusing(fips_at14)
replace fips_at14 = . if !missing(fips_at14) & _merge == 1
drop _merge
* in a small cbsa at birth
replace cbsa_birth_pop2010 = 0 if missing(cbsa_birth_pop2010) & !missing(fips_birth)
gen cbsa_birth_small = 1 if cbsa_birth_pop2010 < $size_big
replace cbsa_birth_small = 0 if missing(cbsa_birth_small) & !missing(fips_birth)
* in a small cbsa at age 14
replace cbsa_at14_pop2010 = 0 if missing(cbsa_at14_pop2010) & !missing(fips_at14)
gen cbsa_at14_small = 1 if cbsa_at14_pop2010 < $size_big
replace cbsa_at14_small = 0 if missing(cbsa_at14_small) & !missing(fips_at14)
* same cbsa at age 14 and junior period
gen cbsa_jun = cbsa if junior_period == 1
gen fips_jun = fips if junior_period == 1
egen cbsa_junior = max(cbsa_jun), by (person_id)
egen fips_junior = max(fips_jun), by (person_id)
gen cbsa_junior_sameas_at14 = 1 if cbsa_junior == cbsa_at14 & !missing(cbsa_junior)
replace cbsa_junior_sameas_at14 = 1 if fips_junior == fips_at14 & !missing(fips_junior) & missing(cbsa_junior_sameas_at14)
replace cbsa_junior_sameas_at14 = 0 if missing(cbsa_junior_sameas_at14) & !missing(fips_at14)

** self-confidence and ability percentiles
* self-confidence percentiles
preserve
collapse (first) self_80_zpctl, by (person_id)
egen self_rank = rank(-self_80_zpctl), track
gen self_pctl = 100 * (1 - (self_rank - 1)/ _N)
keep person_id self_pctl*
save `tmp', replace
restore
merge m:1 person_id using `tmp', nogen
* ability (afqt) percentile
preserve
collapse (first) afqt_80, by (person_id)
egen afqt_rank = rank(-afqt_80), track
gen afqt_pctl = 100 * (1 - (afqt_rank - 1)/ _N)
keep person_id afqt_pctl*
save `tmp', replace
restore
merge m:1 person_id using `tmp', nogen
drop afqt_80 self_80_score self_80_zpctl
* attitude towards risk percentile
preserve
collapse (first) risk_scale, by (person_id)
egen risk_rank = rank(risk_scale), track
gen risk_pctl = 100 * (1 - (risk_rank - 1)/ _N)
keep person_id risk_pctl*
save `tmp', replace
restore
merge m:1 person_id using `tmp', nogen
drop risk_scale

** transform variables
* log wages
gen ln_wage = ln(wage)

** ordering and labeling
drop young age_sen_ age_sen match miss_match cbsa_jun cbsa_junior fips_jun fips_junior
order person_id year junior_period senior_period non_int birth* age sex race hispanic black sample_type educ_enrolled educ_highest educ_highest_life educ_high_school educ_some_college educ_college marital never_married married spouse_wkswk spouse_hrswk spouse_work_26w spouse_work_48w spouse_work_ft any_children child_under7 lfstatus wkswk_li worker_type wage ln_wage tenure experience unemployment outlf occupation* sector* afqt_pctl self_pctl risk_pctl fips_birth fips_at14 fips cbsa_birth cbsa_birth_name cbsa_birth_pop2010 cbsa_birth_small cbsa_birth_type cbsa_at14 cbsa_at14_name cbsa_at14_pop2010 cbsa_at14_small cbsa_at14_type cbsa_junior_sameas_at14 cbsa cbsa_name cbsa_type cbsa_pop2010

label var junior_period "Junior period indicator: One year after completing highest level of education"
label var senior_period "Senior period indicator: 10 years after the junior period"
label var hispanic "Hispanic"
label var black "Black"
label var educ_highest_life "Highest level of education completed (lifetime)"
label var educ_high_school "High-school completed (12 years of education)"
label var educ_some_college "Some college completed (between 13 and 15 years of education)"
label var educ_college "College completed (16 or more years of education)"
label var never_married "Never married"
label var married "Married, spouse present"
label var spouse_work_26w "Spouse worked during previous calendar year (26 or + weeks)"
label var spouse_work_48w "Spouse worked during previous calendar year (48 or + weeks)"
label var spouse_work_ft "Spouse worked full-time during previous calendar year (40 or + weekly hours )"
label var child_under7 "At least one child under 7 years old in household"
label var ln_wage "Log hourly real wage in main job (1982-84 dollars)"
label var cbsa_birth "CBSA id of birth county"
label var cbsa_birth_name "CBSA name of birth county"
label var cbsa_birth_pop2010 "CBSA 2010 population at birth"
label var cbsa_birth_small "Individual was born in small CBSA"
label var cbsa_birth_type "CBSA type of birth county (1 = Metro, 2 = Micro)"
label var cbsa_at14 "CBSA id of county at age 14"
label var cbsa_at14_name "CBSA name of county at age 14"
label var cbsa_at14_pop2010 "CBSA 2010 population at age 14"
label var cbsa_at14_small "Individual was living in small CBSA at age 14"
label var cbsa_at14_type "CBSA type of county at age 14 (1 = Metro, 2 = Micro)"
label var cbsa_junior_sameas_at14 "Same CBSA during the junior period as at age 14"
label var cbsa "CBSA id (2009 definition)"
label var cbsa_name "CBSA name"
label var cbsa_type "CBSA type (1 = Metro, 2 = Micro)"
label var cbsa_pop2010 "CBSA 2010 population"
label var self_pctl "Rosenberg self-confidence percentile, weighted z scores, 1980"
label var afqt_pctl "Cognitive ability AFQT percentile, 1980"
label var risk_pctl "Risk aversion percentile, 2010"

* save panel
compress
label data "'City of dreams' De la Roca, Ottaviano & Puga. NLSY Panel (sample)"
sort person_id year
save ../../data/processed/nlsy_panel_sample, replace
describe


